@@ -33,7 +33,7 @@ from __future__ import print_function
 from future.utils import with_metaclass
 from builtins import int, range
 from copy import deepcopy
-from distutils import spawn
+import shutil
 
 import abc
 import csv
@@ -129,10 +129,10 @@ class OMCSessionHelper():
     if omc_env_home:
       self.omhome = omc_env_home
     else:
-      path_to_omc = spawn.find_executable("omc")
+      path_to_omc = shutil.which("omc")
       if path_to_omc is None:
         raise ValueError("Cannot find OpenModelica executable, please install from openmodelica.org")
-      self.omhome = os.path.split(os.path.split(os.path.realpath(path_to_omc))[0])[0]
+      self.omhome = os.path.dirname(os.path.dirname(path_to_omc))
   def _get_omc_path(self):
     try:
       return os.path.join(self.omhome, 'bin', 'omc')
@@ -860,8 +860,8 @@ class ModelicaSystem(object):
         self.setTempDirectory(customBuildDirectory)
 
         if fileName is not None:
-            self.loadFile(verbose)
             self.loadLibrary(verbose)
+            self.loadFile(verbose)
 
         ## allow directly loading models from MSL without fileName
         if fileName is None and modelName is not None:
@@ -999,13 +999,16 @@ class ModelicaSystem(object):
                 start = None
                 min = None
                 max = None
+                unit = None
                 for att in ch:
                     start = att.get('start')
                     min = att.get('min')
                     max = att.get('max')
+                    unit = att.get('unit')
                 scalar["start"] =start
                 scalar["min"] = min
                 scalar["max"] = max
+                scalar["unit"] = unit
 
                 if(scalar["variability"]=="parameter"):
                     if scalar["name"] in self.overridevariables:
